#include <darts.h>
#include <fstream>
#include <string>

int progress_bar (const char *title, size_t current, size_t total) 
{
  static char bar[] = "*******************************************";
  static int scale = sizeof(bar) - 1;
  static int prev = 0;

  int cur_percentage  = (int)(100.0 * current/total);
  int bar_len         = (int)(1.0   * current*scale/total);

  if (prev != cur_percentage) {
     printf("%s: %3d%% |%.*s%*s| ", title, cur_percentage, bar_len, bar, scale - bar_len, "");
     if (cur_percentage == 100)  printf("\n");
     else                        printf("\r");
     fflush(stdout);
  }
   
  prev = cur_percentage;

  return 1;
};

int main (int argc, char **argv)
{
  if (argc < 3) {
    cerr << "Usage: " << argv[0] << " File Index" << endl;
    exit(0);
  }

  string file  = argv[argc-2];
  string index = argv[argc-1];

  Darts::DoubleArray da;

  string line;
  vector <string> bar;
  istream *is;

  if (file == "-") 
    is = &cin;
  else 
    is = new ifstream (file.c_str());

  if (! *is) {
    cerr << "Cannot Open: " << file << endl;
    exit(-1);
  }

  while (getline(*is, line)) bar.push_back(line);
  if (file != "-") delete is;
   
  char **str  = new char * [bar.size()];
  size_t *len = new size_t [bar.size()];
  for (unsigned int i = 0; i < bar.size(); i++) {
    str[i] = (char *)bar[i].c_str();
    len[i] = strlen (bar[i].c_str());
  }

  da.build (bar.size(), str, len, 0, &progress_bar);
  da.save (index.c_str());
  bar.clear ();
  delete [] str;
  delete [] len;
   
  cout << "Done!, Compression Ratio: " << 
     100.0 * da.getNonzeroSize() / da.getSize() << " %" << endl;

  exit(0);
}
